@@ -34,7 +34,6 @@
 
 #include "knotedisplaysettings.h"
 
-#include "attributes/notelockattribute.h"
 #include "attributes/notelockattribute.h"
 #include "attributes/notealarmattribute.h"
 
@@ -91,11 +90,11 @@
 KNote::KNote(const QDomDocument &buildDoc, const Akonadi::Item &item, bool allowDebugBaloo, QWidget *parent)
     : QFrame(parent, Qt::FramelessWindowHint),
       mItem(item),
-      m_label(Q_NULLPTR),
-      m_grip(Q_NULLPTR),
-      m_button(Q_NULLPTR),
-      m_tool(Q_NULLPTR),
-      m_editor(Q_NULLPTR),
+      m_label(nullptr),
+      m_grip(nullptr),
+      m_button(nullptr),
+      m_tool(nullptr),
+      m_editor(nullptr),
       m_kwinConf(KSharedConfig::openConfig(QStringLiteral("kwinrc"))),
       mDisplayAttribute(new KNoteDisplaySettings),
       mAllowDebugBaloo(allowDebugBaloo)
@@ -513,9 +512,9 @@ void KNote::print(bool preview)
 void KNote::slotSaveAs()
 {
     // TODO: where to put pdf file support? In the printer??!??!
-    QCheckBox *convert = 0;
+    QCheckBox *convert = nullptr;
     if (m_editor->acceptRichText()) {
-        convert = new QCheckBox(0);
+        convert = new QCheckBox(nullptr);
         convert->setText(i18n("Save note as plain text"));
     }
     QUrl url;
@@ -802,6 +801,7 @@ void KNote::createNoteHeader()
 
 void KNote::createNoteEditor(const QString &configFile)
 {
+    Q_UNUSED(configFile);
     m_editor = new KNoteEdit(actionCollection(), this);
     m_noteLayout->addWidget(m_editor);
     m_editor->setNote(this);
@@ -853,7 +853,7 @@ void KNote::createNoteFooter()
 void KNote::loadNoteContent(const Akonadi::Item &item)
 {
     KMime::Message::Ptr noteMessage = item.payload<KMime::Message::Ptr>();
-    const KMime::Headers::Subject *const subject = noteMessage ? noteMessage->subject(false) : Q_NULLPTR;
+    const KMime::Headers::Subject *const subject = noteMessage ? noteMessage->subject(false) : nullptr;
     setName(subject ? subject->asUnicodeString() : QString());
     if (noteMessage->contentType()->isHTMLText()) {
         m_editor->setAcceptRichText(true);
